/**
 * Copyright (c) 1996-2009 Cafesoft, LLC. All Rights Reserved.
 *
 * This software is the confidential and proprietary information of
 * Cafesoft, LLC. ("Confidential Information"). You shall not disclose
 * such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Cafesoft.
 *
 * CAFESOFT MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY
 * OF THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. CAFESOFT SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
 */
package com.cafesoft.cams.auth.callback;

import javax.security.auth.callback.Callback;

import java.util.Map;
import java.util.HashMap;

/**
 * <code>MapCallback</code> provides access to callback values stored
 * as a Map of name/value pairs. Callback values are stored in String
 * representation.
 *
 * @author Norbert K. Kuhnert
 * @version $Revision: 1.3 $ $Date: 2009/08/14 23:49:49 $ $Author: norb $
 * @since 09/23/2008
 */
public class MapCallback implements Callback
{
	/**
	 * The Callback value map.
	 */
	private Map cbMap = null;

	/**
	 * Create a new MapCallback.
	 */
	public MapCallback()
	{
		this.cbMap = new HashMap(5);
	}

	/**
	 * Set a Callback value by name.
	 *
	 * @param name the name associated with the Callback value.
	 * @param value the Callback value (in String representation).
	 */
	public void setCallbackValue(String name, String value)
	{
		if ((name == null) || (value == null))
			return;

		this.cbMap.put(name, value);
	}

	/**
	 * Set Callback values from the contents of another Map.
	 *
	 * @param srcMap the source Map containing the Callback name/value pairs
	 * 	to be copied.
	 */
	public void setCallbackValues(Map srcMap)
	{
		if (srcMap == null)
			return;

		this.cbMap.putAll(srcMap);
	}

	/**
	 * Get a Callback value by name.
	 *
	 * @param name the name associated with the Callback value.
	 * @return the Callback value (in String representation) or null if a
	 * 	value does not exist.
	 */
	public String getCallbackValue(String name)
	{
		if (name == null)
			return null;

		return (String)this.cbMap.get(name);
	}

	/**
	 * Get all Callback values as a Map.
	 *
	 * @return a new Map of Callback values copied from the internal Map.
	 */
	public Map getCallbackValueMap()
	{
		return new HashMap(cbMap);
	}

} // End of class: MapCallback
