/**
 * Copyright (c) 1996-2009 Cafesoft, LLC. All Rights Reserved.
 *
 * This software is the confidential and proprietary information of
 * Cafesoft, LLC. ("Confidential Information"). You shall not disclose
 * such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Cafesoft.
 *
 * CAFESOFT MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY
 * OF THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. CAFESOFT SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
 */
package com.cafesoft.cams.auth.callback;

import javax.security.auth.callback.Callback;

import java.security.cert.X509Certificate;


/**
 * <code>X509CertificateCallback</code> provides access to a chain
 * of <code>X509Certificate</code> instances.
 *
 * @author Norbert K. Kuhnert
 * @version $Revision: 1.3 $ $Date: 2009/08/14 23:49:50 $ $Author: norb $
 * @since 08/25/05
 */
public class X509CertificateCallback implements Callback
{
	/**
	 * The X509Certificate chain as an array
	 */
	private X509Certificate[] x509CertArray;

	/**
	 * Create a new X509CertificateCallback.
	 */
	public X509CertificateCallback()
	{
		this.x509CertArray = null;
	}

	/**
	 * Set the X509Certificate chain.
	 *
	 * @param x509CertArray the X509Certificate chain as an array
	 */
	public void setX509Certificates(X509Certificate[] x509CertArray)
	{
		this.x509CertArray = x509CertArray;
	}

	/**
	 * Get the X509Certificate chain.
	 *
	 * @return the X509Certificate chain as an array or null if an
	 * 	X509Certificate chain is not available.
	 */
	public X509Certificate[] getX509Certificates()
	{
		return this.x509CertArray;
	}

} // End of class: X509CertificateCallback
